/* $Id$ */
#ifndef SHHSCHED_H
#define SHHSCHED_H

#include <sys/time.h>  /* struct timeval */

#ifdef __cplusplus
  extern "C" {
#endif

typedef unsigned long SchedId;

/*
 *  function calls at given times
 */
typedef void (*SchedTimeFunc)(void *clientData);
typedef unsigned long SchedTime; /* milliseconds */

SchedId schedAddTimeAt(struct timeval *when, SchedTimeFunc func,
		       void *clientData);
SchedId schedAddTime(SchedTime delay, SchedTimeFunc func, void *clientData);
void    schedRemoveTime(SchedId id);
void    schedRemoveTimeAll(void);


/*
 *  function calls when file descriptors are ready
 */
typedef void (*SchedDescFunc)(void *clientData, int fd);
typedef enum {
    SCHED_READ_READY,       /* file descriptor ready for reading */
    SCHED_WRITE_READY,      /* file descriptor ready for writing */
    SCHED_EXCEPTION_READY   /* exception waiting on file descriptor */
} SchedDescAction;

SchedId schedAddDesc(SchedDescAction action, int fd,
		     SchedDescFunc func, void *clientData);
void    schedRemoveDesc(SchedId id);
void    schedRemoveDescAll(void);


/*
 *  main loop, and setting up.
 */
void    schedInit(void);
void    schedFinish(void);
void    schedEndLoop(void);
void    schedLoop(void);


#ifdef __cplusplus
  }
#endif

#endif
