/* $Id$ */
/**************************************************************************
 *
 *  FILE            vidclient.c
 *  MODULE OF       vidclient
 *
 *  DESCRIPTION     
 *
 *  WRITTEN BY      Sverre H. Huseby <sverrehu@ifi.uio.no>
 *
 **************************************************************************/

#include <stdlib.h>
#include <stdio.h>

#include <shhmsg.h>
#include <shhopt.h>
#include <shhnet.h>

#include "protocol.h"
#include "shhsched.h"
#include "window.h"
#include "network.h"
#include "vidclient.h"

/**************************************************************************
 *                                                                        *
 *                       P R I V A T E    D A T A                         *
 *                                                                        *
 **************************************************************************/

static SchedId repaintId;



/**************************************************************************
 *                                                                        *
 *                   P R I V A T E    F U N C T I O N S                   *
 *                                                                        *
 **************************************************************************/

static void
vidRepaint(void *clientData)
{
    repaintId = schedAddTime(REPAINT_DELAY, vidRepaint, NULL);
    winRepaint();
}

static void
version(void)
{
    printf(
      "%s " VERSION ", by Sverre H. Huseby "
      "(compiled " COMPILED_DATE " by " COMPILED_BY ")\n",
      msgGetName()
    );
    exit(0);
}

static void
usage(void)
{
    printf(
      "usage: %s [options] remote-host[:remote-port]\n"
      "\n"
      "  -h, --help                     display this help and exit\n"
      "  -V, --version                  output version information and exit\n"
      "  -W, --parent-window=WINDOW-ID  use WINDOW-ID as parent window\n"
      "\n",
      msgGetName()
    );
    exit(0);
}



/**************************************************************************
 *                                                                        *
 *                    P U B L I C    F U N C T I O N S                    *
 *                                                                        *
 **************************************************************************/

void
vidStartRepaint(void)
{
    repaintId = schedAddTime(REPAINT_DELAY, vidRepaint, NULL);
}

void
vidStopRepaint(void)
{
    schedRemoveTime(repaintId);
}

int
main(int argc, char *argv[])
{
    optStruct opt[] = {
      /* short long           type        var/func         special       */
        { 'h', "help",        OPT_FLAG,   usage,           OPT_CALLFUNC },
        { 'V', "version",     OPT_FLAG,   version,         OPT_CALLFUNC },
        { 'W', "parent-window",
	                      OPT_STRING, winSetParentWindow,
	                                                   OPT_CALLFUNC },
        { 0, 0, OPT_END, 0, 0 }  /* no more options */
    };

    msgSetName(argv[0]);
    snSetErrorHandling(SN_REPORT_ERROR_AND_EXIT, msgFatal);

    optParseOptions(&argc, argv, opt, 0);
    if (argc != 2)
	usage();

    netSetRemoteSystem(argv[1]);

    schedInit();
    winInit();
    netInit();

    schedLoop();

    netFinish();
    winFinish();
    schedFinish();
    return 0;
}
